@@ -54,6 +54,22 @@ describe "Blockless Ruby Filters" do
     @d.l(~~Sequel.|(:x, :y)).must_equal '(x OR y)'
   end
 
+  it "should not modifying boolean expression created from array if array is modified" do
+    a = [1]
+    expr = Sequel.expr(:b=>a)
+    @d.l(expr).must_equal '(b IN (1))'
+    a << 2
+    @d.l(expr).must_equal '(b IN (1))'
+  end
+
+  it "should not modifying boolean expression created from string if string is modified" do
+    a = '1'.dup
+    expr = Sequel.expr(:b=>a)
+    @d.l(expr).must_equal "(b = '1')"
+    a << '2'
+    @d.l(expr).must_equal "(b = '1')"
+  end
+
   it "should support = via Hash" do
     @d.l(:x => 100).must_equal '(x = 100)'
     @d.l(:x => 'a').must_equal '(x = \'a\')'
@@ -78,6 +94,12 @@ describe "Blockless Ruby Filters" do
     @d.l(~Sequel.expr(:x => false)).must_equal '(x IS NOT FALSE)'
     @d.l(~Sequel.expr(:x => nil)).must_equal '(x IS NOT NULL)'
   end
+
+  it "should use NOT for inverting boolean expressions where right hand side is function or literal strings" do
+    @d.l(~Sequel.expr(:x => Sequel.function(:any))).must_equal 'NOT (x = any())'
+    @d.l(~Sequel.expr(:x => Sequel.lit('any()'))).must_equal 'NOT (x = any())'
+    @d.l(~Sequel.expr(:x => Sequel.lit('any(?)', 1))).must_equal 'NOT (x = any(1))'
+  end
   
   it "should support = and similar operations via =~ method" do
     @d.l{x =~ 100}.must_equal '(x = 100)'
@@ -1249,7 +1271,7 @@ describe "Sequel::SQL::Wrapper" do
     @ds.literal(s**1).must_equal "power(foo, 1)"
     @ds.literal(s & true).must_equal "(foo AND 't')"
     @ds.literal(s < 1).must_equal "(foo < 1)"
-    @ds.literal(s.sql_subscript(1)).must_equal "foo[1]"
+    @ds.literal(s.sql_subscript(1)).must_equal "(foo)[1]"
     @ds.literal(s.like('a')).must_equal "(foo LIKE 'a' ESCAPE '\\')"
     @ds.literal(s.as(:a)).must_equal "foo AS a"
     @ds.literal(s.cast(Integer)).must_equal "CAST(foo AS integer)"
@@ -1258,8 +1280,12 @@ describe "Sequel::SQL::Wrapper" do
   end
 end
 
-describe "Sequel::SQL::Blob#to_sequel_blob" do
-  it "should return self" do
+describe "Sequel::SQL::Blob" do
+  it ".call should be an alias for .new" do
+    Sequel::SQL::Blob.call('a').must_equal Sequel::SQL::Blob.new('a')
+  end
+
+  it "#to_sequel_blob should return self" do
     c = Sequel::SQL::Blob.new('a')
     c.to_sequel_blob.must_be_same_as(c)
   end
@@ -1280,6 +1306,18 @@ describe Sequel::SQL::Subscript do
     s = @s[2]
     @ds.literal(s).must_equal 'a[1][2]'
   end
+
+  it "should not wrap identifiers in parentheses" do
+    @ds.literal(Sequel::SQL::Subscript.new(:a, [1])).must_equal 'a[1]'
+    @ds.literal(Sequel::SQL::Subscript.new(Sequel[:a], [1])).must_equal 'a[1]'
+    @ds.literal(Sequel::SQL::Subscript.new(Sequel[:a][:b], [1])).must_equal 'a.b[1]'
+  end
+
+  it "should wrap other expression types in parentheses" do
+    @ds.literal(Sequel::SQL::Subscript.new(Sequel.function('a'), [1])).must_equal '(a())[1]'
+    @ds.literal(Sequel::SQL::Subscript.new(Sequel.lit('a'), [1])).must_equal '(a)[1]'
+    @ds.literal(Sequel::SQL::Subscript.new(Sequel.lit('a(?)', 2), [1])).must_equal '(a(2))[1]'
+  end
 end
 
 describe Sequel::SQL::CaseExpression, "#with_merged_expression" do
