@@ -39,6 +39,15 @@ describe "Simple Dataset operations" do
     @ds.order(:id).all.must_equal [{:id=>1, :number=>10}, {:id=>100, :number=>20}]
   end
 
+  it "should support ordering considering NULLS" do
+    @ds.insert(:number=>20)
+    @ds.insert(:number=>nil)
+    @ds.order(Sequel[:number].asc(:nulls=>:first)).select_map(:number).must_equal [nil, 10, 20]
+    @ds.order(Sequel[:number].asc(:nulls=>:last)).select_map(:number).must_equal [10, 20, nil]
+    @ds.order(Sequel[:number].desc(:nulls=>:first)).select_map(:number).must_equal [nil, 20, 10]
+    @ds.order(Sequel[:number].desc(:nulls=>:last)).select_map(:number).must_equal [20, 10, nil]
+  end
+
   it "should have insert return primary key value" do
     @ds.insert(:number=>20).must_equal 2
     @ds.filter(:id=>2).first[:number].must_equal 20
@@ -140,6 +149,10 @@ describe "Simple Dataset operations" do
       rows.must_equal((1..100).map{|i| {:id=>i, :number=>i*10}}.reverse)
     end
 
+    rows = []
+    @ds.order(:number).limit(50, 25).paged_each(:rows_per_fetch=>3).each{|row| rows << row}
+    rows.must_equal((26..75).map{|i| {:id=>i, :number=>i*10}})
+
     rows = []
     @ds.order(:number).limit(50, 25).paged_each(:rows_per_fetch=>3){|row| rows << row}
     rows.must_equal((26..75).map{|i| {:id=>i, :number=>i*10}})
@@ -944,7 +957,7 @@ if DB.dataset.supports_window_functions?
           must_equal [{:sum=>110, :id=>1}, {:sum=>1100, :id=>2}, {:sum=>11000, :id=>3}, {:sum=>110000, :id=>4}, {:sum=>100000, :id=>5}, {:sum=>nil, :id=>6}]
       end
 
-      cspecify "should give correct results for aggregate window functions with offsets for RANGES", :mssql, [proc{DB.server_version < 110000}, :postgres] do
+      cspecify "should give correct results for aggregate window functions with offsets for RANGES", :mssql, :sqlite, [proc{DB.server_version < 110000}, :postgres] do
         @ds.select(:id){sum(:amount).over(:order=>:group_id, :frame=>{:type=>:range, :start=>1}).as(:sum)}.all.
           must_equal [{:sum=>111, :id=>1}, {:sum=>111, :id=>2}, {:sum=>111, :id=>3}, {:sum=>111111, :id=>4}, {:sum=>111111, :id=>5}, {:sum=>111111, :id=>6}]
         @ds.select(:id){sum(:amount).over(:order=>:group_id, :frame=>{:type=>:range, :start=>0, :end=>1}).as(:sum)}.all.
